@@ -6,6 +6,7 @@
                 2001-2005   by Stanislav Visnovsky <visnovsky@kde.org>
                 2006        by Nicolas Goutte <goutte@kde.org>
                 2007-2014   by Nick Shaforostoff <shafff@ukr.net>
+                2018-2019 by Simon Depiets <sdepiets@gmail.com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -139,6 +140,7 @@ void Catalog::clear()
     QUndoStack::clear();
     d._errorIndex.clear();
     d._nonApprovedIndex.clear();
+    d._nonApprovedNonEmptyIndex.clear();
     d._emptyIndex.clear();
     delete m_storage; m_storage = 0;
     d._filePath.clear();
@@ -370,16 +372,20 @@ void Catalog::updateApprovedEmptyIndexCache()
 
     //index cache TODO profile?
     d._nonApprovedIndex.clear();
+    d._nonApprovedNonEmptyIndex.clear();
     d._emptyIndex.clear();
 
     DocPosition pos(0);
     const int limit = m_storage->size();
     while (pos.entry < limit) {
-        if (!isApproved(pos))
-            d._nonApprovedIndex << pos.entry;
         if (m_storage->isEmpty(pos))
             d._emptyIndex << pos.entry;
-
+        if (!isApproved(pos)) {
+            d._nonApprovedIndex << pos.entry;
+            if (!m_storage->isEmpty(pos)) {
+                d._nonApprovedNonEmptyIndex << pos.entry;
+            }
+        }
         ++(pos.entry);
     }
 
@@ -909,10 +915,14 @@ TargetState Catalog::setState(const DocPosition& pos, TargetState state)
         m_storage->setApproved(pos, approved);
     }
 
-    if (!approved)
+    if (!approved) {
         insertInList(d._nonApprovedIndex, pos.entry);
-    else
+        if (!m_storage->isEmpty(pos))
+            insertInList(d._nonApprovedNonEmptyIndex, pos.entry);
+    } else {
         d._nonApprovedIndex.removeAll(pos.entry);
+        d._nonApprovedNonEmptyIndex.removeAll(pos.entry);
+    }
 
     emit signalNumberOfFuzziesChanged();
     emit signalEntryModified(pos);
